# AsyncOrderProcessingOptions

The container for billing processing options and payment processing options.  **Note:** This field is not supported in draft orders. 

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**application_order** | **List[str]** | The priority order to apply credit memos and/or unapplied payments to an invoice. Possible item values are: &#x60;CreditMemo&#x60;, &#x60;UnappliedPayment&#x60;.  **Note:**   - This field is valid only if the &#x60;applyCredit&#x60; field is set to &#x60;true&#x60;.   - If no value is specified for this field, the default priority order is used, [\&quot;CreditMemo\&quot;, \&quot;UnappliedPayment\&quot;], to apply credit memos first and then apply unapplied payments.   - If only one item is specified, only the items of the spedified type are applied to invoices. For example, if the value is &#x60;[\&quot;CreditMemo\&quot;]&#x60;, only credit memos are used to apply to invoices.  | [optional] 
**apply_credit** | **bool** |  - If the value is true, the credit memo or unapplied payment on the order account will be automatically applied to the invoices generated by this order. The credit memo generated by this order will not be automatically applied to any invoices   **Note:** This field is only available if you have [Invoice Settlement](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement) enabled. The Invoice Settlement feature is generally available as of Zuora Billing Release 296 (March 2021). This feature includes Unapplied Payments, Credit and Debit Memo, and Invoice Item Settlement. If you want to enable Invoice Settlement, see [Invoice Settlement Enablement and Checklist Guide](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement/Invoice_Settlement_Migration_Checklist_and_Guide) for more information.  | [optional] 
**apply_credit_balance** | **bool** | Indicates if any credit balance on a customer&#39;s account is automatically applied to invoices. If no value is specified then this field defaults to false. This feature is not available if you have enabled the Invoice Settlement feature.  | [optional] 
**billing_options** | [**BillingOptions**](BillingOptions.md) |  | [optional] 
**collect_payment** | **bool** | Indicates if the current request needs to collect payments. This value can not be &#39;true&#39; when &#39;runBilling&#39; flag is &#39;false&#39;.  | [optional] 
**electronic_payment_options** | [**ElectronicPaymentOptions**](ElectronicPaymentOptions.md) |  | [optional] 
**run_billing** | **bool** | Indicates if the current request needs to generate an invoice. The invoice will be generated against all subscriptions included in this order.  | [optional] 

## Example

```python
from zuora_sdk.models.async_order_processing_options import AsyncOrderProcessingOptions

# TODO update the JSON string below
json = "{}"
# create an instance of AsyncOrderProcessingOptions from a JSON string
async_order_processing_options_instance = AsyncOrderProcessingOptions.from_json(json)
# print the JSON string representation of the object
print(AsyncOrderProcessingOptions.to_json())

# convert the object into a dict
async_order_processing_options_dict = async_order_processing_options_instance.to_dict()
# create an instance of AsyncOrderProcessingOptions from a dict
async_order_processing_options_from_dict = AsyncOrderProcessingOptions.from_dict(async_order_processing_options_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


